package com.ruoyi.frequency.collect.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.controller.req.CollectPageReq;
import com.ruoyi.controller.resp.WorksPageResp;
import com.ruoyi.frequency.collect.entity.Collect;
import com.ruoyi.frequency.collect.model.param.UserCollectNumParam;
import com.ruoyi.frequency.news.entity.News;
import com.ruoyi.post.controller.resp.PostPageResp;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 收藏Mapper接口
 * 
 * @author zj
 * @date 2023-10-16
 */
public interface CollectMapper  extends BaseMapper<Collect>
{
    /**
     * 查询收藏
     * 
     * @param id 收藏主键
     * @return 收藏
     */
    public Collect selectCollectById(Long id);

    /**
     * 查询收藏列表
     * 
     * @param collect 收藏
     * @return 收藏集合
     */
    public List<Collect> selectCollectList(Collect collect);

    /**
     * 新增收藏
     * 
     * @param collect 收藏
     * @return 结果
     */
    public int insertCollect(Collect collect);

    /**
     * 修改收藏
     * 
     * @param collect 收藏
     * @return 结果
     */
    public int updateCollect(Collect collect);

    /**
     * 删除收藏
     * 
     * @param id 收藏主键
     * @return 结果
     */
    public int deleteCollectById(Long id);

    /**
     * 批量删除收藏
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCollectByIds(Long[] ids);

    void collect(@Param("req") Collect collect, @Param("userVo") UserVo userVo);

    Page<WorksPageResp> worksCollectPage(@Param("page") Page<Object> objectPage,@Param("req") CollectPageReq req, @Param("userVo") UserVo userVo);

    Page<PostPageResp> postCollectPage(@Param("page")Page<Object> objectPage, @Param("req") CollectPageReq req, @Param("userVo") UserVo userVo);

    Page<News> newsCollectPage(@Param("page")Page<Object> objectPage, @Param("req") CollectPageReq req, @Param("userVo") UserVo userVo);

    Integer getUserCollectNum( @Param("userVo")UserVo userVo, @Param("req")UserCollectNumParam req);
}
